@@ -17,7 +17,8 @@ public:
     AMeterWidget(QWidget *parent = 0);
     ~AMeterWidget();
 	
-	int setGravity(qreal g);
+    int setGravity(qreal g);
+    void reset();
 
 public slots:
     virtual bool filter(QAccelerometerReading *reading);
@@ -36,7 +37,8 @@ protected:
 
 private:
     qreal r_g;  // 1/g
-	qreal r_a_max;  // 1/a_max
+    qreal r_a_max;  // 1/a_max
+    int in_reset;
 };
 
 #endif // AMETERWIDGET_H
